
readResumeCoords(filePath) {
    return FileRead(filePath)
}

filePath := A_ScriptDir "\ResumeCoords.txt"

if !FileExist(filePath) {
    MsgBox("❌ File not found: " filePath)
    ExitApp
}

try {
    coords := readResumeCoords(filePath)
    coordsParts := StrSplit(Trim(coords), ",")
    resumeX := coordsParts[1]
    resumeY := coordsParts[2]
    MsgBox("📍 Loaded coords: X=" resumeX ", Y=" resumeY)
} catch as e {
    MsgBox("❌ Could not read ResumeCoords.txt.`nError: " e.Message)
    ExitApp
}

running := false
clickCount := 0
exitRequested := false
SetTimer(CheckEscape, 100)

CheckEscape(*) {
    if GetKeyState("Esc", "P") {
        MsgBox("🛑 ESC key pressed — exiting now.")
        ExitApp
    }
}

; InputHook-based Esc capture
listener := InputHook("L0 V")
listener.KeyOpt("{Esc}", "E")
listener.Start()
listener.OnKeyDown := (ih, vk, sc) => (
    vk = "Esc"
        ? (MsgBox("🛑 ESC pressed — stopping now."), ExitApp())
        : ""
)

; GUI
myGui := Gui()
myGui.Title := "Resume Auto Clicker"

myGui.Add("Text",, "Loaded Resume Position:")
posText := myGui.Add("Text", "vPosText", "X: " resumeX ", Y: " resumeY)
myGui.Add("Button", "w200 Default", "Set Current Mouse Position").OnEvent("Click", (*) => SetPosition())
myGui.Add("Button", "w200", "Test Click Now").OnEvent("Click", (*) => TestClick())
myGui.Add("Button", "w200", "▶️ Start Auto Click").OnEvent("Click", (*) => StartAutoClick())
myGui.Add("Button", "w200", "⏹️ Stop Auto Click").OnEvent("Click", (*) => StopAutoClick())

counterText := myGui.Add("Text", "vCounterText", "Clicked 0 times")
statusText := myGui.Add("Text", "vStatusText", "Status: 🔴 Stopped")
myGui.Add("Button", "w200", "Exit").OnEvent("Click", (*) => ExitApp())
myGui.Show("AutoSize")

SetTimer(ShowMousePos, 100)
CoordMode("Mouse", "Screen")

ShowMousePos(*) {
    MouseGetPos &x, &y
    ToolTip("📍 Mouse Position — X: " x "  Y: " y)
}

SetPosition() {
    global resumeX, resumeY, posText
    MouseGetPos &x, &y
    resumeX := x
    resumeY := y
    posText.Text := "X: " x ", Y: " y
    FileDelete("ResumeCoords.txt")
    FileAppend(x "," y, "ResumeCoords.txt")
    MsgBox("✅ Resume position saved: X=" x ", Y=" y)
}

TestClick() {
    global resumeX, resumeY
    MouseMove(resumeX, resumeY, 0)
    Sleep(200)
    Click()
    SoundBeep(1000, 200)
}

StartAutoClick() {
    global running, clickCount, statusText
    running := true
    clickCount := 0
    statusText.Text := "Status: 🟢 Running"
    SetTimer(AutoResume, 2000)
}

StopAutoClick() {
    global running, statusText
    running := false
    SetTimer(AutoResume, 0)
    statusText.Text := "Status: 🔴 Stopped"
}

AutoResume(*) {
    global running, clickCount, resumeX, resumeY, counterText
    if running {
        MouseMove(resumeX, resumeY, 0)
        Click()
        clickCount += 1
        counterText.Text := "Clicked " clickCount " times"
        ToolTip("✅ Clicked Resume " clickCount " at X:" resumeX " Y:" resumeY)
        SoundBeep(1000, 150)
    }
}
